@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2007, Jason Kivlighn (jkivlighn@gmail.com)
@@ -26,10 +25,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-parser.h>
-#include <libtracker-common/tracker-type-utils.h>
-#include <libtracker-common/tracker-utils.h>
+#include <libtracker-common/tracker-common.h>
 
 #include <libtracker-db/tracker-db-dbus.h>
 #include <libtracker-db/tracker-db-interface-sqlite.h>
@@ -40,7 +36,7 @@
 #include "tracker-sparql-query.h"
 
 GPtrArray*
-tracker_data_query_rdf_type (guint32 id)
+tracker_data_query_rdf_type (gint id)
 {
 	TrackerDBCursor *cursor;
 	TrackerDBInterface *iface;
@@ -50,11 +46,11 @@ tracker_data_query_rdf_type (guint32 id)
 	iface = tracker_db_manager_get_db_interface ();
 
 	stmt = tracker_db_interface_create_statement (iface,
-			"SELECT \"rdfs:Resource\".\"Uri\" "
-			"FROM \"rdfs:Resource_rdf:type\" "
-			"INNER JOIN \"rdfs:Resource\" "
-			"ON \"rdfs:Resource_rdf:type\".\"rdf:type\" = \"rdfs:Resource\".\"ID\" "
-			"WHERE \"rdfs:Resource_rdf:type\".\"ID\" = ?");
+	                                              "SELECT \"rdfs:Resource\".\"Uri\" "
+	                                              "FROM \"rdfs:Resource_rdf:type\" "
+	                                              "INNER JOIN \"rdfs:Resource\" "
+	                                              "ON \"rdfs:Resource_rdf:type\".\"rdf:type\" = \"rdfs:Resource\".\"ID\" "
+	                                              "WHERE \"rdfs:Resource_rdf:type\".\"ID\" = ?");
 
 	tracker_db_statement_bind_int (stmt, 0, id);
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
@@ -63,7 +59,7 @@ tracker_data_query_rdf_type (guint32 id)
 	if (cursor) {
 
 		/* Query is usually a rather small result, but let's try to
-		 * avoid reallocs in gptrarray.c as much as possible (this 
+		 * avoid reallocs in gptrarray.c as much as possible (this
 		 * function is called fairly often) */
 
 		ret = g_ptr_array_sized_new (20);
@@ -76,20 +72,20 @@ tracker_data_query_rdf_type (guint32 id)
 	return ret;
 }
 
-guint32
-tracker_data_query_resource_id (const gchar	   *uri)
+gint
+tracker_data_query_resource_id (const gchar *uri)
 {
 	TrackerDBCursor *cursor;
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-	guint32		    id = 0;
+	gint id = 0;
 
 	g_return_val_if_fail (uri != NULL, 0);
 
 	iface = tracker_db_manager_get_db_interface ();
 
 	stmt = tracker_db_interface_create_statement (iface,
-		"SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?");
+	                                              "SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?");
 	tracker_db_statement_bind_text (stmt, 0, uri);
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -105,7 +101,7 @@ tracker_data_query_resource_id (const gchar	   *uri)
 
 TrackerDBResultSet *
 tracker_data_query_sparql (const gchar  *query,
-			   GError      **error)
+                           GError      **error)
 {
 	TrackerSparqlQuery *sparql_query;
 	TrackerDBResultSet *result_set;
