@@ -33,6 +33,7 @@
 
 #include <libtracker-db/tracker-db-manager.h>
 #include <libtracker-db/tracker-db-dbus.h>
+#include <libtracker-db/tracker-db-journal.h>
 
 #include "tracker-data-manager.h"
 #include "tracker-data-update.h"
@@ -64,7 +65,7 @@ struct _TrackerDataUpdateBuffer {
 struct _TrackerDataUpdateBufferResource {
 	gchar *subject;
 	gchar *new_subject;
-	guint32 id;
+	gint id;
 	gboolean create;
 	gboolean fts_updated;
 	/* TrackerProperty -> GValueArray */
@@ -115,10 +116,12 @@ struct _TrackerCommitDelegate {
 };
 
 static gboolean in_transaction = FALSE;
+static gboolean in_journal_replay = FALSE;
 static TrackerDataUpdateBuffer update_buffer;
 /* current resource */
 static TrackerDataUpdateBufferResource *resource_buffer;
 static TrackerDataBlankBuffer blank_buffer;
+static time_t resource_time = 0;
 
 static GPtrArray *insert_callbacks = NULL;
 static GPtrArray *delete_callbacks = NULL;
@@ -193,14 +196,14 @@ GQuark tracker_data_error_quark (void) {
 	return g_quark_from_static_string ("tracker_data_error-quark");
 }
 
-static guint32
+static gint
 tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
 {
 	TrackerDBCursor    *cursor;
 	TrackerDBInterface *temp_iface;
 	TrackerDBStatement *stmt;
 
-	static guint32      max = 0;
+	static gint         max = 0;
 
 	if (G_LIKELY (max != 0)) {
 		return ++max;
@@ -222,13 +225,13 @@ tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
 	return ++max;
 }
 
-static guint32
+static gint
 tracker_data_update_get_next_modseq (void)
 {
 	TrackerDBCursor    *cursor;
 	TrackerDBInterface *temp_iface;
 	TrackerDBStatement *stmt;
-	static guint32      max = 0;
+	static gint         max = 0;
 
 	if (G_LIKELY (max != 0)) {
 		return ++max;
@@ -352,34 +355,39 @@ cache_delete_value (const gchar            *table_name,
 	g_array_append_val (table->properties, property);
 }
 
-static guint32
+static gint
 query_resource_id (const gchar *uri)
 {
-	guint32 id;
+	gint id;
 
-	id = GPOINTER_TO_UINT (g_hash_table_lookup (update_buffer.resource_cache, uri));
+	id = GPOINTER_TO_INT (g_hash_table_lookup (update_buffer.resource_cache, uri));
 
 	if (id == 0) {
 		id = tracker_data_query_resource_id (uri);
 
 		if (id) {
-			g_hash_table_insert (update_buffer.resource_cache, g_strdup (uri), GUINT_TO_POINTER (id));
+			g_hash_table_insert (update_buffer.resource_cache, g_strdup (uri), GINT_TO_POINTER (id));
 		}
 	}
 
 	return id;
 }
 
-static guint32
-ensure_resource_id (const gchar *uri)
+static gint
+ensure_resource_id (const gchar *uri,
+                    gboolean    *create)
 {
 	TrackerDBInterface *iface, *common;
 	TrackerDBStatement *stmt;
 
-	guint32 id;
+	gint id;
 
 	id = query_resource_id (uri);
 
+	if (create) {
+		*create = (id == 0);
+	}
+
 	if (id == 0) {
 		/* object resource not yet in the database */
 		common = tracker_db_manager_get_db_interface ();
@@ -389,12 +397,17 @@ ensure_resource_id (const gchar *uri)
 		stmt = tracker_db_interface_create_statement (iface, "INSERT INTO \"rdfs:Resource\" (ID, Uri, \"tracker:added\", \"tracker:modified\", Available) VALUES (?, ?, ?, ?, 1)");
 		tracker_db_statement_bind_int (stmt, 0, id);
 		tracker_db_statement_bind_text (stmt, 1, uri);
-		tracker_db_statement_bind_int64 (stmt, 2, (gint64) time (NULL));
+		g_warn_if_fail  (resource_time != 0);
+		tracker_db_statement_bind_int64 (stmt, 2, (gint64) resource_time);
 		tracker_db_statement_bind_int (stmt, 3, tracker_data_update_get_next_modseq ());
 		tracker_db_statement_execute (stmt, NULL);
 		g_object_unref (stmt);
 
-		g_hash_table_insert (update_buffer.resource_cache, g_strdup (uri), GUINT_TO_POINTER (id));
+		if (!in_journal_replay) {
+			tracker_db_journal_append_resource (id, uri);
+		}
+
+		g_hash_table_insert (update_buffer.resource_cache, g_strdup (uri), GINT_TO_POINTER (id));
 	}
 
 	return id;
@@ -491,7 +504,7 @@ tracker_data_resource_buffer_flush (GError **error)
 				/* remove entry from rdf:type table */
 				stmt = tracker_db_interface_create_statement (iface, "DELETE FROM \"rdfs:Resource_rdf:type\" WHERE ID = ? AND \"rdf:type\" = ?");
 				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-				tracker_db_statement_bind_int (stmt, 1, ensure_resource_id (tracker_class_get_uri (table->class)));
+				tracker_db_statement_bind_int (stmt, 1, ensure_resource_id (tracker_class_get_uri (table->class), NULL));
 				tracker_db_statement_execute (stmt, &actual_error);
 				g_object_unref (stmt);
 
@@ -500,6 +513,64 @@ tracker_data_resource_buffer_flush (GError **error)
 					return;
 				}
 
+				if (table->class) {
+					tracker_class_set_count (table->class, tracker_class_get_count (table->class) - 1);
+				}
+
+				if (strcmp (table_name, "rdfs:Resource") == 0) {
+					TrackerProperty **properties, *property;
+					guint n_props;
+					gboolean first;
+
+					/* never delete Uri <-> ID mapping to avoid dangling references,
+					   do remove property values, though */
+
+					sql = g_string_new ("UPDATE \"rdfs:Resource\" SET");
+					first = TRUE;
+
+					properties = tracker_ontology_get_properties (&n_props);
+					for (i = 0; i < n_props; i++) {
+						property = properties[i];
+
+						if (tracker_property_get_multiple_values (property)) {
+							continue;
+						}
+
+						if (strcmp (tracker_class_get_name (tracker_property_get_domain (property)), table_name) == 0) {
+							if (strcmp (tracker_property_get_name (property), "tracker:added") == 0 ||
+							    strcmp (tracker_property_get_name (property), "tracker:modified") == 0) {
+								/* do not touch tracker:added or tracker:modified */
+								continue;
+							}
+
+							/* set all other property columns to NULL */
+							if (first) {
+								first = FALSE;
+							} else {
+								g_string_append (sql, ",");
+							}
+							g_string_append_printf (sql, " \"%s\" = NULL",
+										tracker_property_get_name (property));
+						}
+					}
+
+					g_string_append (sql, " WHERE ID = ?");
+
+					stmt = tracker_db_interface_create_statement (iface, "%s", sql->str);
+					tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+					tracker_db_statement_execute (stmt, &actual_error);
+					g_object_unref (stmt);
+
+					g_string_free (sql, TRUE);
+
+					if (actual_error) {
+						g_propagate_error (error, actual_error);
+						return;
+					}
+
+					continue;
+				}
+
 				/* remove row from class table */
 				stmt = tracker_db_interface_create_statement (iface, "DELETE FROM \"%s\" WHERE ID = ?", table_name);
 				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
@@ -642,7 +713,8 @@ static void
 tracker_data_blank_buffer_flush (GError **error)
 {
 	/* end of blank node */
-	gint i, id;
+	gint i;
+	gint id;
 	gchar *subject;
 	gchar *blank_uri;
 	const gchar *sha1;
@@ -693,9 +765,9 @@ tracker_data_blank_buffer_flush (GError **error)
 		g_free (g_array_index (blank_buffer.predicates, gchar *, i));
 		g_free (g_array_index (blank_buffer.objects, gchar *, i));
 	}
-	g_array_free (blank_buffer.graphs, TRUE);
-	g_array_free (blank_buffer.predicates, TRUE);
-	g_array_free (blank_buffer.objects, TRUE);
+	g_array_remove_range (blank_buffer.graphs, 0, blank_buffer.graphs->len);
+	g_array_remove_range (blank_buffer.predicates, 0, blank_buffer.predicates->len);
+	g_array_remove_range (blank_buffer.objects, 0, blank_buffer.objects->len);
 
 	g_hash_table_insert (blank_buffer.table, subject, blank_uri);
 	g_checksum_free (checksum);
@@ -736,7 +808,7 @@ cache_create_service_decomposed (TrackerClass *cl,
 
 	cache_insert_row (cl);
 
-	g_value_set_int (&gvalue, ensure_resource_id (tracker_class_get_uri (cl)));
+	g_value_set_int (&gvalue, ensure_resource_id (tracker_class_get_uri (cl), NULL));
 	cache_insert_value ("rdfs:Resource_rdf:type", "rdf:type", &gvalue, TRUE, FALSE);
 
 	tracker_class_set_count (cl, tracker_class_get_count (cl) + 1);
@@ -837,11 +909,6 @@ check_property_domain (TrackerProperty *property)
 static GValueArray *
 get_property_values (TrackerProperty *property)
 {
-	TrackerDBInterface *iface;
-	TrackerDBStatement *stmt;
-	TrackerDBResultSet *result_set;
-	gchar              *table_name;
-	const gchar        *field_name;
 	gboolean            multiple_values;
 	GValueArray        *old_values;
 
@@ -850,16 +917,22 @@ get_property_values (TrackerProperty *property)
 	old_values = g_value_array_new (multiple_values ? 4 : 1);
 	g_hash_table_insert (resource_buffer->predicates, g_object_ref (property), old_values);
 
-	if (multiple_values) {
-		table_name = g_strdup_printf ("%s_%s",
-		                              tracker_class_get_name (tracker_property_get_domain (property)),
-		                              tracker_property_get_name (property));
-	} else {
-		table_name = g_strdup (tracker_class_get_name (tracker_property_get_domain (property)));
-	}
-	field_name = tracker_property_get_name (property);
-
 	if (!resource_buffer->create) {
+		TrackerDBInterface *iface;
+		TrackerDBStatement *stmt;
+		TrackerDBResultSet *result_set;
+		gchar              *table_name;
+		const gchar        *field_name;
+
+		if (multiple_values) {
+			table_name = g_strdup_printf ("%s_%s",
+				                      tracker_class_get_name (tracker_property_get_domain (property)),
+				                      tracker_property_get_name (property));
+		} else {
+			table_name = g_strdup (tracker_class_get_name (tracker_property_get_domain (property)));
+		}
+		field_name = tracker_property_get_name (property);
+
 		iface = tracker_db_manager_get_db_interface ();
 
 		stmt = tracker_db_interface_create_statement (iface, "SELECT \"%s\" FROM \"%s\" WHERE ID = ?", field_name, table_name);
@@ -887,9 +960,9 @@ get_property_values (TrackerProperty *property)
 			g_object_unref (result_set);
 		}
 		g_object_unref (stmt);
-	}
 
-	g_free (table_name);
+		g_free (table_name);
+	}
 
 	return old_values;
 }
@@ -963,7 +1036,7 @@ string_to_gvalue (const gchar         *value,
                   TrackerPropertyType  type,
                   GValue              *gvalue)
 {
-	guint32                     object_id;
+	gint object_id;
 
 	switch (type) {
 	case TRACKER_PROPERTY_TYPE_STRING:
@@ -990,7 +1063,7 @@ string_to_gvalue (const gchar         *value,
 		g_value_set_int (gvalue, tracker_string_to_date (value));
 		break;
 	case TRACKER_PROPERTY_TYPE_RESOURCE:
-		object_id = ensure_resource_id (value);
+		object_id = ensure_resource_id (value, NULL);
 		g_value_init (gvalue, G_TYPE_INT);
 		g_value_set_int (gvalue, object_id);
 		break;
@@ -1211,8 +1284,6 @@ cache_delete_resource_type (TrackerClass *class,
 
 	cache_delete_row (class);
 
-	tracker_class_set_count (class, tracker_class_get_count (class) - 1);
-
 	if (delete_callbacks) {
 		guint n;
 		for (n = 0; n < delete_callbacks->len; n++) {
@@ -1259,7 +1330,7 @@ tracker_data_delete_statement (const gchar  *graph,
 		/* subject not yet in cache, retrieve or create ID */
 		resource_buffer = g_slice_new0 (TrackerDataUpdateBufferResource);
 		resource_buffer->subject = g_strdup (subject);
-		resource_buffer->id = query_resource_id (resource_buffer->subject);
+		resource_buffer->id = subject_id;
 		resource_buffer->fts_updated = FALSE;
 		resource_buffer->types = tracker_data_query_rdf_type (resource_buffer->id);
 		resource_buffer->predicates = g_hash_table_new_full (g_direct_hash, g_direct_equal, g_object_unref, (GDestroyNotify) g_value_array_free);
@@ -1271,6 +1342,12 @@ tracker_data_delete_statement (const gchar  *graph,
 	if (object && g_strcmp0 (predicate, RDF_PREFIX "type") == 0) {
 		class = tracker_ontology_get_class_by_uri (object);
 		if (class != NULL) {
+			if (!in_journal_replay) {
+				tracker_db_journal_append_delete_statement_id (resource_buffer->id,
+					tracker_data_query_resource_id (predicate),
+					query_resource_id (object));
+			}
+
 			cache_delete_resource_type (class, graph);
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_CLASS,
@@ -1279,6 +1356,19 @@ tracker_data_delete_statement (const gchar  *graph,
 	} else {
 		field = tracker_ontology_get_property_by_uri (predicate);
 		if (field != NULL) {
+			gint id = tracker_property_get_id (field);
+			if (!in_journal_replay) {
+				if (tracker_property_get_data_type (field) == TRACKER_PROPERTY_TYPE_RESOURCE) {
+					tracker_db_journal_append_delete_statement_id (resource_buffer->id,
+						(id != 0) ? id : tracker_data_query_resource_id (predicate),
+						query_resource_id (object));
+				} else {
+					tracker_db_journal_append_delete_statement (resource_buffer->id,
+						(id != 0) ? id : tracker_data_query_resource_id (predicate),
+						object);
+				}
+			}
+
 			delete_metadata_decomposed (field, object, error);
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_PROPERTY,
@@ -1327,9 +1417,11 @@ tracker_data_insert_statement_common (const gchar            *graph,
 
 		if (blank_buffer.subject == NULL) {
 			blank_buffer.subject = g_strdup (subject);
-			blank_buffer.graphs = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
-			blank_buffer.predicates = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
-			blank_buffer.objects = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
+			if (blank_buffer.graphs == NULL) {
+				blank_buffer.graphs = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
+				blank_buffer.predicates = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
+				blank_buffer.objects = g_array_sized_new (FALSE, FALSE, sizeof (char*), 4);
+			}
 		}
 
 		value = g_strdup (graph);
@@ -1355,11 +1447,9 @@ tracker_data_insert_statement_common (const gchar            *graph,
 		/* subject not yet in cache, retrieve or create ID */
 		resource_buffer = g_slice_new0 (TrackerDataUpdateBufferResource);
 		resource_buffer->subject = g_strdup (subject);
-		resource_buffer->id = query_resource_id (resource_buffer->subject);
-		resource_buffer->create = (resource_buffer->id == 0);
+		resource_buffer->id = ensure_resource_id (resource_buffer->subject, &resource_buffer->create);
 		resource_buffer->fts_updated = FALSE;
 		if (resource_buffer->create) {
-			resource_buffer->id = ensure_resource_id (resource_buffer->subject);
 			resource_buffer->types = g_ptr_array_new ();
 		} else {
 			resource_buffer->types = tracker_data_query_rdf_type (resource_buffer->id);
@@ -1416,6 +1506,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 	GError          *actual_error = NULL;
 	TrackerClass    *class;
 	TrackerProperty *property;
+	gint             prop_id = 0;
 
 	g_return_if_fail (subject != NULL);
 	g_return_if_fail (predicate != NULL);
@@ -1431,10 +1522,13 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 			             "Property '%s' not found in the ontology", predicate);
 			return;
 		}
-	} else if (tracker_property_get_data_type (property) != TRACKER_PROPERTY_TYPE_RESOURCE) {
-		g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_INVALID_TYPE,
-		             "Property '%s' does not accept URIs", predicate);
-		return;
+	} else {
+		if (tracker_property_get_data_type (property) != TRACKER_PROPERTY_TYPE_RESOURCE) {
+			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_INVALID_TYPE,
+			             "Property '%s' does not accept URIs", predicate);
+			return;
+		}
+		prop_id = tracker_property_get_id (property);
 	}
 
 	/* subjects and objects starting with `:' are anonymous blank nodes */
@@ -1516,6 +1610,12 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 			}
 		}
 	}
+
+	if (!in_journal_replay) {
+		tracker_db_journal_append_insert_statement_id (resource_buffer->id,
+			(prop_id != 0) ? prop_id : tracker_data_query_resource_id (predicate),
+			query_resource_id (object));
+	}
 }
 
 void
@@ -1527,6 +1627,7 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 {
 	GError          *actual_error = NULL;
 	TrackerProperty *property;
+	gint             id = 0;
 
 	g_return_if_fail (subject != NULL);
 	g_return_if_fail (predicate != NULL);
@@ -1538,10 +1639,13 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 		g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_PROPERTY,
 		             "Property '%s' not found in the ontology", predicate);
 		return;
-	} else if (tracker_property_get_data_type (property) == TRACKER_PROPERTY_TYPE_RESOURCE) {
-		g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_INVALID_TYPE,
-		             "Property '%s' only accepts URIs", predicate);
-		return;
+	} else {
+		if (tracker_property_get_data_type (property) == TRACKER_PROPERTY_TYPE_RESOURCE) {
+			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_INVALID_TYPE,
+			             "Property '%s' only accepts URIs", predicate);
+			return;
+		}
+		id = tracker_property_get_id (property);
 	}
 
 	if (!tracker_data_insert_statement_common (graph, subject, predicate, object, &actual_error)) {
@@ -1572,6 +1676,12 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 			                    delegate->user_data);
 		}
 	}
+
+	if (!in_journal_replay) {
+		tracker_db_journal_append_insert_statement (resource_buffer->id,
+			(id != 0) ? id : tracker_data_query_resource_id (predicate),
+			object);
+	}
 }
 
 static void
@@ -1794,8 +1904,13 @@ tracker_data_begin_transaction (void)
 
 	g_return_if_fail (!in_transaction);
 
-	update_buffer.resource_cache = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-	update_buffer.resources = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) resource_buffer_free);
+	resource_time = time (NULL);
+
+	if (update_buffer.resource_cache == NULL) {
+		update_buffer.resource_cache = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+		update_buffer.resources = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) resource_buffer_free);
+	}
+
 	resource_buffer = NULL;
 	if (blank_buffer.table == NULL) {
 		blank_buffer.table = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
@@ -1808,6 +1923,14 @@ tracker_data_begin_transaction (void)
 	in_transaction = TRUE;
 }
 
+void
+tracker_data_begin_replay_transaction (time_t time)
+{
+	in_journal_replay = TRUE;
+	tracker_data_begin_transaction ();
+	resource_time = time;
+}
+
 void
 tracker_data_commit_transaction (void)
 {
@@ -1828,8 +1951,8 @@ tracker_data_commit_transaction (void)
 
 	tracker_db_interface_end_transaction (iface);
 
-	g_hash_table_unref (update_buffer.resources);
-	g_hash_table_unref (update_buffer.resource_cache);
+	g_hash_table_remove_all (update_buffer.resources);
+	g_hash_table_remove_all (update_buffer.resource_cache);
 
 	if (commit_callbacks) {
 		guint n;
@@ -1839,6 +1962,8 @@ tracker_data_commit_transaction (void)
 			delegate->callback (delegate->user_data);
 		}
 	}
+
+	in_journal_replay = FALSE;
 }
 
 static void
@@ -1878,8 +2003,8 @@ tracker_data_delete_resource_description (const gchar *graph,
 	TrackerDBStatement *stmt;
 	TrackerDBResultSet *result_set, *single_result, *multi_result;
 	TrackerClass       *class;
-	GString                    *sql;
-	TrackerProperty           **properties, *property;
+	GString            *sql;
+	TrackerProperty   **properties, *property;
 	int                 i;
 	gboolean            first, bail_out = FALSE;
 	gint                resource_id;
@@ -2058,14 +2183,16 @@ tracker_data_update_sparql (const gchar  *update,
 	iface = tracker_db_manager_get_db_interface ();
 
 	sparql_query = tracker_sparql_query_new_update (update);
-
+	resource_time = time (NULL);
 	tracker_db_interface_execute_query (iface, NULL, "SAVEPOINT sparql");
+	tracker_db_journal_start_transaction (resource_time);
 
 	tracker_sparql_query_execute_update (sparql_query, FALSE, &actual_error);
 
 	if (actual_error) {
 		tracker_data_update_buffer_clear ();
 		tracker_db_interface_execute_query (iface, NULL, "ROLLBACK TO sparql");
+		tracker_db_journal_rollback_transaction ();
 
 		if (rollback_callbacks) {
 			guint n;
@@ -2082,6 +2209,8 @@ tracker_data_update_sparql (const gchar  *update,
 		return;
 	}
 
+	tracker_db_journal_commit_transaction ();
+	resource_time = 0;
 	tracker_db_interface_execute_query (iface, NULL, "RELEASE sparql");
 
 	g_object_unref (sparql_query);
@@ -2103,13 +2232,16 @@ tracker_data_update_sparql_blank (const gchar  *update,
 
 	sparql_query = tracker_sparql_query_new_update (update);
 
+	resource_time = time (NULL);
 	tracker_db_interface_execute_query (iface, NULL, "SAVEPOINT sparql");
+	tracker_db_journal_start_transaction (resource_time);
 
 	blank_nodes = tracker_sparql_query_execute_update (sparql_query, TRUE, &actual_error);
 
 	if (actual_error) {
 		tracker_data_update_buffer_clear ();
 		tracker_db_interface_execute_query (iface, NULL, "ROLLBACK TO sparql");
+		tracker_db_journal_rollback_transaction ();
 
 		if (rollback_callbacks) {
 			guint n;
@@ -2126,6 +2258,8 @@ tracker_data_update_sparql_blank (const gchar  *update,
 		return NULL;
 	}
 
+	tracker_db_journal_commit_transaction ();
+	resource_time = 0;
 	tracker_db_interface_execute_query (iface, NULL, "RELEASE sparql");
 
 	g_object_unref (sparql_query);
@@ -2133,3 +2267,9 @@ tracker_data_update_sparql_blank (const gchar  *update,
 	return blank_nodes;
 }
 
+void
+tracker_data_sync (void)
+{
+	tracker_db_journal_fsync ();
+}
+
