@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
  *
@@ -48,18 +47,22 @@ typedef enum {
 	TRACKER_DB_MANAGER_READONLY         = 1 << 5
 } TrackerDBManagerFlags;
 
-GType               tracker_db_get_type                         (void) G_GNUC_CONST;
-gboolean            tracker_db_manager_init             (TrackerDBManagerFlags  flags,
-                                                         gboolean              *first_time,
-                                                         gboolean               shared_cache,
-                                                         gboolean              *need_journal);
-void                tracker_db_manager_shutdown         (void);
-void                tracker_db_manager_remove_all       (gboolean               rm_backup_and_log);
-void                tracker_db_manager_optimize         (void);
-const gchar *       tracker_db_manager_get_file         (TrackerDB              db);
-TrackerDBInterface *tracker_db_manager_get_db_interface (void);
-void                tracker_db_manager_disconnect       (void);
-void                tracker_db_manager_reconnect        (void);
+GType               tracker_db_get_type                  (void) G_GNUC_CONST;
+gboolean            tracker_db_manager_init              (TrackerDBManagerFlags  flags,
+                                                          gboolean              *first_time,
+                                                          gboolean               shared_cache);
+void                tracker_db_manager_shutdown          (void);
+void                tracker_db_manager_remove_all        (gboolean               rm_journal);
+void                tracker_db_manager_optimize          (void);
+const gchar *       tracker_db_manager_get_file          (TrackerDB              db);
+TrackerDBInterface *tracker_db_manager_get_db_interface  (void);
+void                tracker_db_manager_remove_temp       (void);
+void                tracker_db_manager_move_to_temp      (void);
+void                tracker_db_manager_restore_from_temp (void);
+void                tracker_db_manager_init_locations    (void);
+
+TrackerDBManagerFlags
+                    tracker_db_manager_get_flags         (void);
 
 G_END_DECLS
 
