@@ -33,10 +33,14 @@
 #include <glib/gstdio.h>
 
 #include <libtracker-common/tracker-common.h>
+
 #include <libtracker-db/tracker-db.h>
+
 #include <libtracker-miner/tracker-miner-manager.h>
 #include <libtracker-miner/tracker-crawler.h>
 
+#include "tracker-miner-files-reindex-client.h"
+
 #define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
 
@@ -47,14 +51,14 @@
 	"\n" \
 	"  http://www.gnu.org/licenses/gpl.txt\n"
 
-static gboolean     should_kill;
-static gboolean     should_terminate;
-static gboolean     hard_reset;
-static gboolean     soft_reset;
-static gboolean     remove_config;
-static gboolean     remove_thumbnails;
-static gboolean     start;
-static gboolean     print_version;
+static gboolean should_kill;
+static gboolean should_terminate;
+static gboolean hard_reset;
+static gboolean soft_reset;
+static gboolean remove_config;
+static gboolean start;
+static const gchar **reindex_mime_types;
+static gboolean print_version;
 
 static GOptionEntry entries[] = {
 	{ "kill", 'k', 0, G_OPTION_ARG_NONE, &should_kill,
@@ -73,12 +77,12 @@ static GOptionEntry entries[] = {
 	{ "remove-config", 'c', 0, G_OPTION_ARG_NONE, &remove_config,
 	  N_("Remove all configuration files so they are re-generated on next start"),
 	  NULL },
-	{ "remove-thumbnails", 'i', 0, G_OPTION_ARG_NONE, &remove_thumbnails,
-	  N_("Remove all thumbnail files so they are re-generated"),
-	  NULL },
 	{ "start", 's', 0, G_OPTION_ARG_NONE, &start,
 	  N_("Starts miners (which indirectly starts tracker-store too)"),
 	  NULL },
+	{ "reindex-mime-type", 'm', 0, G_OPTION_ARG_STRING_ARRAY, &reindex_mime_types,
+	  N_("Reindex files which match the mime type supplied (for new extractors), use -m MIME1 -m MIME2"),
+	  N_("MIME") },
 	{ "version", 'V', 0, G_OPTION_ARG_NONE, &print_version,
 	  N_("Print version"),
 	  NULL },
@@ -250,7 +254,7 @@ main (int argc, char **argv)
 	 * don't iterate them.
 	 */
 	if (should_kill || should_terminate ||
-	    (!start && !remove_config && !remove_thumbnails)) {
+	    (!start && !remove_config)) {
 		pids = get_pids ();
 		str = g_strdup_printf (g_dngettext (NULL,
 		                                    "Found %d PID…",
@@ -401,43 +405,6 @@ main (int argc, char **argv)
 		g_object_unref (crawler);
 	}
 
-	if (remove_thumbnails) {
-		GMainLoop *main_loop;
-		GFile *file;
-		TrackerCrawler *crawler;
-		const gchar *home_dir;
-		gchar *path;
-
-		crawler = tracker_crawler_new ();
-		main_loop = g_main_loop_new (NULL, FALSE);
-
-		g_signal_connect (crawler, "check-file",
-		                  G_CALLBACK (crawler_check_file_cb),
-		                  NULL);
-		g_signal_connect (crawler, "finished",
-		                  G_CALLBACK (crawler_finished_cb),
-		                  main_loop);
-
-		/* Go through service files */
-		home_dir = g_getenv ("HOME");
-
-		if (!home_dir) {
-			home_dir = g_get_home_dir ();
-		}
-
-		path = g_build_path (G_DIR_SEPARATOR_S, home_dir, ".thumbnails", NULL);
-		file = g_file_new_for_path (path);
-		g_free (path);
-
-		g_print ("%s\n", _("Removing thumbnails files…"));
-
-		tracker_crawler_start (crawler, file, TRUE);
-		g_object_unref (file);
-
-		g_main_loop_run (main_loop);
-		g_object_unref (crawler);
-	}
-
 	if (start) {
 		TrackerMinerManager *manager;
 		GSList *miners, *l;
@@ -475,5 +442,48 @@ main (int argc, char **argv)
 		g_slist_free (miners);
 	}
 
+	if (reindex_mime_types) {
+		DBusGConnection *connection;
+		DBusGProxy *proxy;
+	
+		GError *error = NULL;
+
+		connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+		
+		if (!connection) {
+			g_print ("Could not connect to the D-Bus session bus, %s",
+			         error ? error->message : "no error given.");
+			g_clear_error (&error);
+			return FALSE;
+		}
+		
+		/* The definitions below (DBUS_SERVICE_DBUS, etc) are
+		 * predefined for us to just use (dbus_g_proxy_...)
+		 */
+		proxy = dbus_g_proxy_new_for_name (connection,
+		                                   "org.freedesktop.Tracker1.Miner.Files.Reindex",
+		                                   "/org/freedesktop/Tracker1/Miner/Files/Reindex",
+		                                   "org.freedesktop.Tracker1.Miner.Files.Reindex");
+		
+		if (!proxy) {
+			g_print ("Could not create a proxy for the D-Bus service, %s",
+			         error ? error->message : "no error given.");
+			g_clear_error (&error);
+			return FALSE;
+		}
+		
+		if (!org_freedesktop_Tracker1_Miner_Files_Reindex_mime_types (proxy, 
+		                                                              reindex_mime_types, 
+		                                                              &error)) {
+			g_print ("Could not reindex mime types, %s",
+			         error ? error->message : "no error given.");
+			g_clear_error (&error);
+			g_object_unref (proxy);
+			return FALSE;
+		}
+
+		g_object_unref (proxy);
+	}
+
 	return EXIT_SUCCESS;
 }
