@@ -91,70 +91,6 @@ strcasestr (const gchar *haystack,
 
 #endif /* HAVE_STRCASESTR */
 
-/* NOTE: This function was stolen from GLib 2.18.x. Since upstream and
- * the Maemo branch don't have this in circulation yet, we have copied
- * it here. This can be removed an replaced with
- * g_file_make_directory_with_parents() when we get it. -mr
- */
-static gboolean
-make_directory_with_parents (GFile         *file,
-                             GCancellable  *cancellable,
-                             GError       **error)
-{
-	gboolean result;
-	GFile *parent_file, *work_file;
-	GList *list = NULL, *l;
-	GError *my_error = NULL;
-
-	if (g_cancellable_set_error_if_cancelled (cancellable, error))
-		return FALSE;
-
-	result = g_file_make_directory (file, cancellable, &my_error);
-	if (result || my_error->code != G_IO_ERROR_NOT_FOUND)
-		{
-			if (my_error)
-				g_propagate_error (error, my_error);
-			return result;
-		}
-
-	work_file = file;
-
-	while (!result && my_error->code == G_IO_ERROR_NOT_FOUND)
-		{
-			g_clear_error (&my_error);
-
-			parent_file = g_file_get_parent (work_file);
-			if (parent_file == NULL)
-				break;
-			result = g_file_make_directory (parent_file, cancellable, &my_error);
-
-			if (!result && my_error->code == G_IO_ERROR_NOT_FOUND)
-				list = g_list_prepend (list, parent_file);
-
-			work_file = parent_file;
-		}
-
-	for (l = list; result && l; l = l->next)
-		{
-			result = g_file_make_directory ((GFile *) l->data, cancellable, &my_error);
-		}
-
-	/* Clean up */
-	while (list != NULL)
-		{
-			g_object_unref ((GFile *) list->data);
-			list = g_list_remove (list, list->data);
-		}
-
-	if (!result)
-		{
-			g_propagate_error (error, my_error);
-			return result;
-		}
-
-	return g_file_make_directory (file, cancellable, error);
-}
-
 static gboolean
 albumart_strip_find_next_block (const gchar    *original,
                                 const gunichar  open_char,
@@ -581,26 +517,6 @@ albumart_heuristic (const gchar *artist,
 	return retval;
 }
 
-static void
-albumart_signal_queue_thumbnail (const gchar *file,
-                                 const gchar *mime)
-{
-	GObject *object;
-
-	object = tracker_dbus_get_object (TRACKER_TYPE_EXTRACT);
-	if (!object) {
-		/* This can happen if we run tracker-extract on the
-		 * command line for one file only because we don't
-		 * register the TrackerExtract object with DBus.
-		 */
-		return;
-	}
-
-	g_message ("Album art being signaled for thumbnail queue for file:'%s', mime:'%s'",
-	           file, mime);
-	g_signal_emit_by_name (object, "queue-thumbnail", file, mime);
-}
-
 static gboolean
 albumart_set (const unsigned char *buffer,
               size_t               len,
@@ -621,7 +537,6 @@ albumart_set (const unsigned char *buffer,
 
 	retval = tracker_albumart_buffer_to_jpeg (buffer, len, mime, local_path);
 
-	albumart_signal_queue_thumbnail (local_path, mime);
 	g_free (local_path);
 
 	return retval;
@@ -737,7 +652,7 @@ albumart_copy_to_local (TrackerStorage *hal,
 			GFile *dirf;
 
 			dirf = g_file_get_parent (local_file);
-			make_directory_with_parents (dirf, NULL, NULL);
+			g_file_make_directory_with_parents (dirf, NULL, NULL);
 			g_object_unref (dirf);
 
 			g_debug ("Copying album art from:'%s' to:'%s'",
@@ -779,15 +694,6 @@ albumart_queue_cb (DBusGProxy     *proxy,
 
 	if (info->hal && info->art_path &&
 	    g_file_test (info->art_path, G_FILE_TEST_EXISTS)) {
-		gchar *uri;
-
-		uri = g_filename_to_uri (info->art_path, NULL, NULL);
-
-		g_debug ("Downloaded album art using D-Bus service for uri:'%s'",
-		         uri);
-
-		albumart_signal_queue_thumbnail (uri, "image/jpeg");
-		g_free (uri);
 
 		albumart_copy_to_local (info->hal,
 		                        info->art_path,
@@ -963,9 +869,6 @@ tracker_albumart_process (const unsigned char *buffer,
 			}
 		}
 
-		if (processed) {
-			albumart_signal_queue_thumbnail (filename_uri, "image/jpeg");
-		}
 	} else {
 		g_debug ("Album art already exists for uri:'%s' as '%s'",
 		         filename_uri,
