@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2007, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008-2009, Nokia
@@ -37,10 +36,9 @@
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-os-dependant.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-ontology.h>
 
-#include "tracker-main.h"
+#include <libtracker-extract/tracker-extract.h>
 
 #ifndef HAVE_GETLINE
 
@@ -57,17 +55,17 @@
 #endif /* HAVE_GETLINE */
 
 #ifdef USING_UNZIPPSFILES
-static void extract_ps_gz (const gchar *uri,
-			   TrackerSparqlBuilder *metadata);
+static void extract_ps_gz (const gchar          *uri,
+                           TrackerSparqlBuilder *metadata);
 #endif
-static void extract_ps	  (const gchar *uri,
-			   TrackerSparqlBuilder *metadata);
+static void extract_ps    (const gchar          *uri,
+                           TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 #ifdef USING_UNZIPPSFILES
-	{ "application/x-gzpostscript",	extract_ps_gz },
+	{ "application/x-gzpostscript", extract_ps_gz },
 #endif /* USING_UNZIPPSFILES */
-	{ "application/postscript",	extract_ps    },
+	{ "application/postscript",     extract_ps    },
 	{ NULL, NULL }
 };
 
@@ -75,9 +73,9 @@ static TrackerExtractData data[] = {
 
 static ssize_t
 igetdelim (gchar  **linebuf,
-	   size_t  *linebufsz,
-	   gint     delimiter,
-	   FILE    *file)
+           size_t  *linebufsz,
+           gint     delimiter,
+           FILE    *file)
 {
 	gint ch;
 	gint idx;
@@ -129,8 +127,8 @@ igetdelim (gchar  **linebuf,
 
 static gint
 getline (gchar **s,
-	 guint	*lim,
-	 FILE	*stream)
+         guint  *lim,
+         FILE   *stream)
 {
 	return igetdelim (s, lim, '\n', stream);
 }
@@ -179,24 +177,24 @@ date_to_iso8601 (const gchar *date)
 	if (date && date[1] && date[2]) {
 		if (date[0] == '(') {
 			/* we have probably a date like
-			 * "(18:07 Tuesday 22 May 2007)" 
+			 * "(18:07 Tuesday 22 May 2007)"
 			 */
 			return hour_day_str_day (date);
 		} else if (g_ascii_isalpha (date[0])) {
 			/* we have probably a date like
-			 * "Tue May 22 18:07:10 2007" 
+			 * "Tue May 22 18:07:10 2007"
 			 */
 			return day_str_month_day (date);
 
 		} else if (date[1] == ' ' || date[2] == ' ') {
 			/* we have probably a date like
-			 * "22 May 1997 18:07:10 -0600" 
+			 * "22 May 1997 18:07:10 -0600"
 			 */
 			return day_month_year_date (date);
 
 		} else if (date[1] == ':' || date[2] == ':') {
 			/* we have probably a date like
-			 * "6:07 PM May 22, 2007" 
+			 * "6:07 PM May 22, 2007"
 			 */
 			return hour_month_day_date (date);
 		}
@@ -207,14 +205,14 @@ date_to_iso8601 (const gchar *date)
 
 static void
 extract_ps (const gchar          *uri,
-	    TrackerSparqlBuilder *metadata)
+            TrackerSparqlBuilder *metadata)
 {
 	FILE *f;
 	gchar *filename;
 	gchar *line;
 	gsize length;
 	gssize read_char;
-	
+
 	filename = g_filename_from_uri (uri, NULL, NULL);
 	f = tracker_file_open (filename, "r", TRUE);
 	g_free (filename);
@@ -229,7 +227,7 @@ extract_ps (const gchar          *uri,
 	tracker_sparql_builder_subject_iri (metadata, uri);
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:PaginatedTextDocument");
-	
+
 	while ((read_char = getline (&line, &length, f)) != -1) {
 		gboolean pageno_atend = FALSE;
 		gboolean header_finished = FALSE;
@@ -293,7 +291,7 @@ extract_ps (const gchar          *uri,
 
 static void
 extract_ps_gz (const gchar          *uri,
-	       TrackerSparqlBuilder *metadata)
+               TrackerSparqlBuilder *metadata)
 {
 	FILE *fz, *f;
 	GError *error = NULL;
@@ -303,10 +301,10 @@ extract_ps_gz (const gchar          *uri,
 	gboolean ptat;
 	const gchar *argv[4];
 	gchar *filename;
-	
+
 	fd = g_file_open_tmp ("tracker-extract-ps-gunzipped.XXXXXX",
-			      &gunzipped,
-			      &error);
+	                      &gunzipped,
+	                      &error);
 
 	if (error) {
 		g_error_free (error);
@@ -323,16 +321,16 @@ extract_ps_gz (const gchar          *uri,
 	argv[3] = NULL;
 
 	ptat = g_spawn_async_with_pipes (g_get_tmp_dir (),
-					 (gchar **) argv,
-					 NULL,
-					 G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
-					 tracker_spawn_child_func,
-					 GINT_TO_POINTER (10),
-					 NULL,
-					 NULL,
-					 &fdz,
-					 NULL,
-					 &error);
+	                                 (gchar **) argv,
+	                                 NULL,
+	                                 G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
+	                                 tracker_spawn_child_func,
+	                                 GINT_TO_POINTER (10),
+	                                 NULL,
+	                                 NULL,
+	                                 &fdz,
+	                                 NULL,
+	                                 &error);
 
 	if (!ptat) {
 		g_free (filename);
@@ -390,7 +388,7 @@ extract_ps_gz (const gchar          *uri,
 #endif /* USING_UNZIPPSFILES */
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
