@@ -212,7 +212,7 @@ tracker_statistics_get (TrackerStatistics      *object,
 	request_id = tracker_dbus_get_next_request_id ();
 
 	tracker_dbus_request_block_hooks ();
-	tracker_dbus_request_new (request_id, __FUNCTION__);
+	tracker_dbus_request_new (request_id, context, "%s()", __FUNCTION__);
 
 	priv = TRACKER_STATISTICS_GET_PRIVATE (object);
 
@@ -246,7 +246,7 @@ tracker_statistics_get (TrackerStatistics      *object,
 	g_ptr_array_foreach (values, (GFunc) g_strfreev, NULL);
 	g_ptr_array_free (values, TRUE);
 
-	tracker_dbus_request_success (request_id);
+	tracker_dbus_request_success (request_id, context);
 	tracker_dbus_request_unblock_hooks ();
 }
 
