@@ -128,7 +128,7 @@ main (int argc, char **argv)
 
 	g_option_context_free (context);
 
-	client = tracker_connect (FALSE, G_MAXINT);
+	client = tracker_client_new (0, G_MAXINT);
 
 	if (!client) {
 		g_printerr ("%s\n",
@@ -181,10 +181,10 @@ main (int argc, char **argv)
 
 			length = results->len;
 
-			g_print (tracker_dngettext (NULL,
-			                            "Result: %d",
-			                            "Results: %d",
-			                            length),
+			g_print (g_dngettext (NULL,
+			                      "Result: %d",
+			                      "Results: %d",
+			                      length),
 			         length);
 			g_print ("\n");
 
@@ -196,7 +196,7 @@ main (int argc, char **argv)
 		g_print ("\n");
 	}
 
-	tracker_disconnect (client);
+	g_object_unref (client);
 
 	return EXIT_SUCCESS;
 }
